@@ -6,6 +6,7 @@
  * inotify cron system
  * 
  * Copyright (C) 2006, 2007, 2008 Lukas Jelinek, <lukas@aiken.cz>
+ * Copyright (C) 2014, 2015 Andreas Altair Redmer, <altair.ibn.la.ahad.sy@gmail.com>
  * 
  * This program is free software; you can use it, redistribute
  * it and/or modify it under the terms of the GNU General Public
@@ -22,14 +23,6 @@
 
 #include "strtok.h"
 
-/*
-/// Incron user table base directory
-#define INCRON_USER_TABLE_BASE "/var/spool/incron/"
-
-/// Incron system table base directory
-#define INCRON_SYS_TABLE_BASE "/etc/incron.d/"
-*/
-
 /// Incron table entry class.
 class IncronTabEntry
 {
@@ -107,6 +100,24 @@ public:
     return m_fNoLoop;
   }
   
+  /// Checks whether this entry has set recursion-avoidance.
+  /**
+   * \return true = no recursion, false = recursion allowed
+   */
+  inline bool IsNoRecursion() const
+  {
+    return m_fNoRecursion;
+  }
+  
+  /// Checks whether this entry has set dotdir-avoidance. true = dotdirs are included; false = dotdirs are excluded
+  /**
+   * \return true = no recursion, false = recursion allowed
+   */
+  inline bool IsDotDirs() const
+  {
+    return m_fDotDirs;
+  }
+  
   /// Add backslashes before spaces in the source path.
   /**
    * It also adds backslashes before all original backslashes
@@ -127,6 +138,8 @@ protected:
   uint32_t m_uMask;   ///< event mask
   std::string m_cmd;  ///< command string
   bool m_fNoLoop;     ///< no loop yes/no
+  bool m_fNoRecursion;///< no recursion yes/no
+  bool m_fDotDirs;    ///< dotdir included yes/no
 };
 
 
